:orphan:

######
API
######

The exact API of all functions and classes, as given by the docstrings.

.. _soma_ref:

:mod:`soma.pipeline`: Pipeline
===============================

.. automodule:: soma.pipeline
   :no-members:
   :no-inherited-members:

**User guide:** See the :ref:`soma_guide` section for further details.

.. currentmodule:: soma.pipeline

Pipeline Definition
--------------------
.. autosummary::
    :toctree: generated/soma-pipeline/
    :template: class.rst

    pipeline.Pipeline

Node Types
-----------
.. autosummary::
    :toctree: generated/soma-pipeline/
    :template: class.rst

    pipeline.Node
    pipeline.ProcessNode
    pipeline.PipelineNode
    pipeline.Switch

Plug
-----
.. autosummary::
    :toctree: generated/soma-pipeline/
    :template: class.rst

    pipeline.Plug


:mod:`soma.process`: Process
===============================

.. automodule:: soma.process
   :no-members:
   :no-inherited-members:

**User guide:** See the :ref:`soma_guide` section for further details.

.. currentmodule:: soma.process

.. autosummary::
    :toctree: generated/soma-process/
    :template: class.rst

    process.Process

.. autosummary::
    :toctree: generated/soma-process/
    :template: function.rst

    loader.get_process_instance


:mod:`soma.study_config`: Study Configuration
==============================================

.. automodule:: soma.study_config
   :no-members:
   :no-inherited-members:

**User guide:** See the :ref:`soma_guide` section for further details.

.. currentmodule:: soma.study_config

.. autosummary::
    :toctree: generated/soma-studyconfig/
    :template: class.rst

    study_config.StudyConfig


:mod:`soma.controller`: Traits
==============================

.. automodule:: soma.controller
   :no-members:
   :no-inherited-members:

.. currentmodule:: soma.controller

.. autosummary::
    :toctree: generated/soma-traits/
    :template: function.rst

    trait_utils.trait_ids




